@@ -1,7 +1,7 @@
 package App::BencherUtils;
 
-our $DATE = '2016-01-21'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -129,6 +129,11 @@ _
             schema => ['float*', between=>[0,1]],
             tags => ['category:bencher'],
         },
+        note => {
+            summary => 'Additional note, passed to bencher',
+            schema => 'str*',
+            tags => ['category:bencher'],
+        },
     },
     features => {
         dry_run => 1,
@@ -537,7 +542,7 @@ App::BencherUtils - Utilities related to bencher
 
 =head1 VERSION
 
-This document describes version 0.06 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-21.
+This document describes version 0.07 of App::BencherUtils (from Perl distribution App-BencherUtils), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
@@ -604,6 +609,10 @@ Add to the start of @INC.
 
 Remove entries from @INC.
 
+=item * B<note> => I<str>
+
+Additional note, passed to bencher.
+
 =item * B<precision_limit> => I<float>
 
 Precision limit, passed to bencher.
@@ -665,6 +674,10 @@ Scenario patterns to include.
 
 Scenarios to include.
 
+=item * B<note> => I<str>
+
+Additional note, passed to bencher.
+
 =item * B<precision_limit> => I<float>
 
 Precision limit, passed to bencher.
